# Generated by Django 5.0.3 on 2024-03-19 05:36

import encrypted_model_fields.fields
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("translator", "0019_alter_openaitranslator_model"),
    ]

    operations = [
        migrations.CreateModel(
            name="MoonshotAITranslator",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "name",
                    models.CharField(max_length=100, unique=True, verbose_name="Name"),
                ),
                ("valid", models.BooleanField(null=True, verbose_name="Valid")),
                (
                    "api_key",
                    encrypted_model_fields.fields.EncryptedCharField(
                        verbose_name="API Key"
                    ),
                ),
                (
                    "base_url",
                    models.URLField(
                        default="https://api.moonshot.cn/v1", verbose_name="API URL"
                    ),
                ),
                (
                    "model",
                    models.CharField(
                        choices=[
                            ("moonshot-v1-8k", "moonshot-v1-8k"),
                            ("moonshot-v1-32k", "moonshot-v1-32k"),
                            ("moonshot-v1-128k", "moonshot-v1-128k"),
                        ],
                        default="moonshot-v1-8k",
                        max_length=100,
                    ),
                ),
                (
                    "prompt",
                    models.TextField(
                        default="Translate only the text from the following into {target_language},only returns translations.\n{text}"
                    ),
                ),
                ("temperature", models.FloatField(default=0.5)),
                ("top_p", models.FloatField(default=0.95)),
                ("frequency_penalty", models.FloatField(default=0)),
                ("presence_penalty", models.FloatField(default=0)),
                ("max_tokens", models.IntegerField(default=1000)),
            ],
            options={
                "verbose_name": "Moonshot AI",
                "verbose_name_plural": "Moonshot AI",
            },
        ),
    ]



import logging
from django.contrib import admin
from django.conf import settings
from django.utils.html import format_html
from .models import *

class BaseTranslatorAdmin(admin.ModelAdmin):
    def save_model(self, request, obj, form, change):
        logging.info("Call save_model: %s", obj)
        obj.valid = None
        obj.save()
        try:
            obj.valid = obj.validate()
        except Exception as e:
            obj.valid = False
            logging.error("Error in django_text_translator: %s", e)
        finally:
            obj.save()

    def is_valid(self, obj):
        if obj.valid is None:
            return format_html(
                "<img src='/static/img/icon-loading.svg' alt='In Progress'>"
            )
        elif obj.valid is True:
            return format_html(
                "<img src='/static/admin/img/icon-yes.svg' alt='Succeed'>"
            )
        else:
            return format_html(
                "<img src='/static/admin/img/icon-no.svg' alt='Error'>"
            )

    is_valid.short_description = 'Valid'

    def masked_api_key(self, obj):
        api_key = obj.api_key if hasattr(obj, "api_key") else obj.token
        if api_key:
            return f"{api_key[:3]}...{api_key[-3:]}"
        return ""
    masked_api_key.short_description = "API Key"

@admin.register(OpenAITranslator)
class OpenAITranslatorAdmin(BaseTranslatorAdmin):
    fields = ["name", "api_key", "base_url", "model", "prompt", "temperature", "top_p", "frequency_penalty",
              "presence_penalty", "max_tokens",  "summary_prompt"]
    list_display = ["name", "is_valid", "masked_api_key", "model", "prompt", "max_tokens", "base_url",  "summary_prompt"]


@admin.register(AzureAITranslator)
class AzureAITranslatorAdmin(BaseTranslatorAdmin):
    fields = ["name", "api_key", "endpoint", "version", "deloyment_name", "prompt", "temperature", "top_p",
              "frequency_penalty", "presence_penalty", "max_tokens",  "summary_prompt"]
    list_display = ["name", "is_valid", "masked_api_key", "deloyment_name", "version", "prompt", "max_tokens", "endpoint",  "summary_prompt"]


@admin.register(DeepLTranslator)
class DeepLTranslatorAdmin(BaseTranslatorAdmin):
    fields = ["name", "api_key", "server_url", "proxy", "max_characters"]
    list_display = ["name", "is_valid", "masked_api_key", "server_url", "proxy", "max_characters"]


@admin.register(DeepLXTranslator)
class DeepLXTranslatorAdmin(BaseTranslatorAdmin):
    fields = ["name", "deeplx_api", "interval", "max_characters"]
    list_display = ["name", "is_valid", "deeplx_api", "interval", "max_characters"]


# @admin.register(DeepLWebTranslator)
class DeepLWebTranslatorAdmin(BaseTranslatorAdmin):
    fields = ["name", "interval", "proxy", "max_characters"]
    list_display = ["name", "is_valid", "interval", "proxy", "max_characters"]

@admin.register(MicrosoftTranslator)
class MicrosoftTranslatorAdmin(BaseTranslatorAdmin):
    fields = ["name", "api_key", "location", "endpoint", "max_characters"]
    list_display = ["name", "is_valid", "masked_api_key", "location", "endpoint", "max_characters"]


@admin.register(CaiYunTranslator)
class CaiYunTranslatorAdmin(BaseTranslatorAdmin):
    fields = ["name", "token", "url", "max_characters"]
    list_display = ["name", "is_valid", "masked_api_key", "url", "max_characters"]


@admin.register(GeminiTranslator)
class GeminiTranslatorAdmin(BaseTranslatorAdmin):
    fields = ["name", "api_key", "model", "prompt", "temperature", "top_p", "top_k", "max_tokens",  "summary_prompt", "interval"]
    list_display = ["name", "is_valid", "masked_api_key", "model", "prompt", "max_tokens",  "summary_prompt", "interval"]


@admin.register(GoogleTranslateWebTranslator)
class GoogleTranslateWebTranslatorAdmin(BaseTranslatorAdmin):
    fields = ["name", "base_url", "interval", "proxy", "max_characters"]
    list_display = ["name", "is_valid", "base_url", "proxy", "interval", "max_characters"]

@admin.register(ClaudeTranslator)
class ClaudeTranslatorAdmin(BaseTranslatorAdmin):
    fields = ["name", "api_key", "base_url", "model", "prompt", "temperature", "top_p", "top_k", "max_tokens",  "summary_prompt", "proxy"]
    list_display = ["name", "is_valid", "masked_api_key", "model", "prompt", "max_tokens", "base_url",  "summary_prompt"]

@admin.register(MoonshotAITranslator)
class MoonshotAITranslatorAdmin(BaseTranslatorAdmin):
    fields = ["name", "api_key", "base_url", "model", "prompt", "temperature", "top_p", "frequency_penalty",
              "presence_penalty", "max_tokens",  "summary_prompt"]
    list_display = ["name", "is_valid", "masked_api_key", "model", "prompt", "max_tokens", "base_url",  "summary_prompt"]

if settings.DEBUG:
    @admin.register(Translated_Content)
    class Translated_ContentAdmin(admin.ModelAdmin):
        fields = ["original_content", "translated_content", "translated_language", "tokens", "characters"]
        list_display = ["original_content", "translated_language", "translated_content", "tokens", "characters"]
    
        # def has_change_permission(self, request, obj=None):
        #     return False

        # def has_add_permission(self, request):
        #     return False


    @admin.register(TestTranslator)
    class TestTranslatorAdmin(BaseTranslatorAdmin):
        fields = ["name", "translated_text", "max_characters", "interval"]
        list_display = ["name", "is_valid", "translated_text", "max_characters", "interval"]


from .base import TranslatorEngine
import logging
from django.db import models
from time import sleep
from django.utils.translation import gettext_lazy as _


class TestTranslator(TranslatorEngine):
    translated_text = models.TextField(default="@@Translated Text@@")
    max_characters = models.IntegerField(default=50000)
    interval = models.IntegerField(_("Request Interval(s)"), default=3)

    class Meta:
        verbose_name = "Test"
        verbose_name_plural = "Test"

    def validate(self) -> bool:
        return True

    def translate(self, text:str, target_language:str) -> dict:
        logging.info(">>> Test Translate [%s]: %s", target_language, text)
        sleep(self.interval)
        return {'text': f"{target_language} {self.translated_text} {text}", "tokens": 0, "characters": len(text)}


# Generated by Django 5.0.3 on 2024-03-25 02:26

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('translator', '0021_alter_claudetranslator_model'),
    ]

    operations = [
        migrations.AlterField(
            model_name='geminitranslator',
            name='model',
            field=models.CharField(choices=[('gemini-pro', 'gemini-pro'), ('gemini-1.5-pro', 'gemini-1.5-pro')], default='gemini-pro', max_length=100),
        ),
    ]



# Generated by Django 5.0.1 on 2024-01-30 08:58

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ('translator', '0006_testtranslator_alter_openaitranslator_prompt'),
    ]

    operations = [
        migrations.AddField(
            model_name='caiyuntranslator',
            name='max_characters',
            field=models.IntegerField(default=5000),
        ),
        migrations.AddField(
            model_name='deepltranslator',
            name='max_characters',
            field=models.IntegerField(default=5000),
        ),
        migrations.AddField(
            model_name='deeplxtranslator',
            name='max_characters',
            field=models.IntegerField(default=50000),
        ),
        migrations.AddField(
            model_name='microsofttranslator',
            name='max_characters',
            field=models.IntegerField(default=5000),
        ),
    ]



# Generated by Django 5.0.3 on 2024-04-16 02:27

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("translator", "0022_alter_geminitranslator_model"),
    ]

    operations = [
        migrations.AddField(
            model_name="azureaitranslator",
            name="summary_prompt",
            field=models.TextField(
                default="Summarize the following text in {target_language}:\n{text}"
            ),
        ),
        migrations.AddField(
            model_name="claudetranslator",
            name="summary_prompt",
            field=models.TextField(
                default="Summarize the following text in {target_language}:\n{text}"
            ),
        ),
        migrations.AddField(
            model_name="geminitranslator",
            name="summary_prompt",
            field=models.TextField(
                default="Summarize the following text in {target_language}:\n{text}"
            ),
        ),
        migrations.AddField(
            model_name="moonshotaitranslator",
            name="summary_prompt",
            field=models.TextField(
                default="Summarize the following text in {target_language}:\n{text}"
            ),
        ),
        migrations.AddField(
            model_name="openaitranslator",
            name="summary_prompt",
            field=models.TextField(
                default="Summarize the following text in {target_language}:\n{text}"
            ),
        ),
        migrations.AlterField(
            model_name="googletranslatewebtranslator",
            name="base_url",
            field=models.URLField(
                default="https://translate.googleapis.com/translate_a/single",
                verbose_name="URL",
            ),
        ),
        migrations.AlterField(
            model_name="openaitranslator",
            name="model",
            field=models.CharField(
                choices=[
                    ("gpt-3.5-turbo", "gpt-3.5-turbo"),
                    ("gpt-4-turbo", "gpt-4-turbo"),
                ],
                default="gpt-3.5-turbo",
                max_length=100,
            ),
        ),
    ]



# Generated by Django 5.0.1 on 2024-01-26 15:22

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ('translator', '0003_azureaitranslator_openaitranslator_frequency_penalty_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='openaitranslator',
            name='model',
            field=models.CharField(
                choices=[('gpt-3.5-turbo', 'gpt-3.5-turbo'), ('gpt-3.5-turbo-16k', 'gpt-3.5-turbo-16k'),
                         ('gpt-4', 'gpt-4'), ('gpt-4-32k', 'gpt-4-32k')], default='gpt-3.5-turbo', max_length=100),
        ),
    ]



# Generated by Django 5.0.3 on 2024-03-17 00:24

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('translator', '0018_alter_claudetranslator_model'),
    ]

    operations = [
        migrations.AlterField(
            model_name='openaitranslator',
            name='model',
            field=models.CharField(choices=[('gpt-3.5-turbo', 'gpt-3.5-turbo'), ('gpt-4-turbo-preview', 'gpt-4-turbo-preview')], default='gpt-3.5-turbo', max_length=100),
        ),
    ]



# Generated by Django 5.0.3 on 2024-03-21 00:36

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("translator", "0020_moonshotaitranslator"),
    ]

    operations = [
        migrations.AlterField(
            model_name="claudetranslator",
            name="model",
            field=models.CharField(
                choices=[
                    ("claude-3-haiku-20240307", "claude-3-haiku-20240307"),
                    ("claude-3-sonnet-20240229", "claude-3-sonnet-20240229"),
                    ("claude-3-opus-20240229", "claude-3-opus-20240229"),
                ],
                default="claude-instant-1.2",
                max_length=50,
            ),
        ),
    ]



# Generated by Django 5.0.2 on 2024-02-20 07:43

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("translator", "0014_testtranslator_interval"),
    ]

    operations = [
        migrations.AddField(
            model_name="googletranslatewebtranslator",
            name="max_characters",
            field=models.IntegerField(default=5000),
        ),
    ]



import google.generativeai as genai
from .base import TranslatorEngine
import logging
from time import sleep
from django.db import models
from encrypted_model_fields.fields import EncryptedCharField
from django.utils.translation import gettext_lazy as _

class GeminiTranslator(TranslatorEngine):
    # https://ai.google.dev/tutorials/python_quickstart

    # base_url = models.URLField(_("API URL"), default="https://generativelanguage.googleapis.com/v1beta/")
    api_key = EncryptedCharField(_("API Key"), max_length=255)
    model = models.CharField(max_length=100, default="gemini-pro", help_text="e.g. gemini-pro, gemini-1.5-pro")
    prompt = models.TextField(
        default="Translate only the text from the following into {target_language},only returns translations.\n{text}")
    temperature = models.FloatField(default=0.5)
    top_p = models.FloatField(default=1)
    top_k = models.IntegerField(default=1)
    max_tokens = models.IntegerField(default=1000)
    interval = models.IntegerField(_("Request Interval(s)"), default=3)

    summary_prompt = models.TextField(default="Summarize the following text in {target_language}:\n{text}")


    class Meta:
        verbose_name = "Google Gemini"
        verbose_name_plural = "Google Gemini"

    def _init(self):
        genai.configure(api_key=self.api_key)
        return genai.GenerativeModel(self.model)

    def validate(self) -> bool:
        if self.api_key:
            try:
                model = self._init()
                res = model.generate_content("hi")
                return res.candidates[0].finish_reason.name == "STOP"
            except Exception as e:
                return False

    def translate(self, text:str, target_language:str, prompt:str=None) -> dict:
        logging.info(">>> Gemini Translate [%s]:", target_language)
        model = self._init()
        tokens = 0
        translated_text = ''
        prompt = prompt or self.prompt
        try:
            prompt = prompt.format(target_language=target_language, text=text)
            generation_config = genai.types.GenerationConfig(
                candidate_count=1,
                temperature=self.temperature,
                top_p=self.top_p,
                top_k=self.top_k,
                max_output_tokens=self.max_tokens
            )
            res = model.generate_content(prompt, generation_config=generation_config)
            finish_reason = res.candidates[0].finish_reason.name if res.candidates else None
            if finish_reason == "STOP":
                translated_text = res.text
            else:
                translated_text = ''
                logging.info("GeminiTranslator finish_reason->%s: %s", finish_reason, text)
            tokens = model.count_tokens(prompt).total_tokens
        except Exception as e:
            logging.error("GeminiTranslator->%s: %s", e, text)
        finally:
            sleep(self.interval)

        return {'text': translated_text, "tokens": tokens}
    
    def summarize(self, text:str, target_language:str) -> dict:
        logging.info(">>> Gemini Summarize [%s]:", target_language)
        return self.translate(text, target_language, self.summary_prompt)




import uuid
import json
import httpx
from .base import TranslatorEngine
import logging
from django.db import models
from encrypted_model_fields.fields import EncryptedCharField
from django.utils.translation import gettext_lazy as _


class CaiYunTranslator(TranslatorEngine):
    # https://docs.caiyunapp.com/blog/2018/09/03/lingocloud-api/
    token = EncryptedCharField(max_length=255)
    url = models.URLField(max_length=255, default="http://api.interpreter.caiyunai.com/v1/translator")
    max_characters = models.IntegerField(default=5000)
    language_code_map = {
        "English": "en",
        "Chinese Simplified": "zh",
        "Japanese": "ja",
        "Korean": "ko",
        "Spanish": "es",
        "French": "fr",
        "Russian": "ru",
    }

    class Meta:
        verbose_name = "CaiYun"
        verbose_name_plural = "CaiYun"

    def validate(self) -> bool:
        result = self.translate("Hi", "Chinese Simplified")
        return result.get("text") != ""

    def translate(self, text: str, target_language: str) -> dict:
        logging.info(">>> CaiYun Translate [%s]: %s", target_language, text)
        target_code = self.language_code_map.get(target_language, None)
        translated_text = ''
        try:
            if target_code is None:
                logging.error("CaiYunTranslator->Not support target language:%s", target_language)

            payload = {
                "source": text,
                "trans_type": f"auto2{target_code}",
                "request_id": uuid.uuid4().hex,
                "detect": True,
            }

            headers = {
                "content-type": "application/json",
                "x-authorization": f"token {self.token}",
            }

            resp = httpx.post(url=self.url, headers=headers, data=json.dumps(payload), timeout=10)
            resp.raise_for_status()
            translated_text = resp.json()["target"]
        except Exception as e:
            logging.error("CaiYunTranslator->%s: %s", e, text)
        finally:
            return {'text': translated_text, "characters": len(text)}




# Generated by Django 5.0.1 on 2024-02-12 09:11

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ('translator', '0008_geminitranslator'),
    ]

    operations = [
        migrations.AddField(
            model_name='deepltranslator',
            name='proxy',
            field=models.URLField(blank=True, null=True, verbose_name='Proxy(optional)'),
        ),
        migrations.AddField(
            model_name='deepltranslator',
            name='server_url',
            field=models.URLField(blank=True, null=True, verbose_name='API URL(optional)'),
        ),
    ]



# Generated by Django 5.0.1 on 2024-01-25 11:56

import encrypted_model_fields.fields
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ('translator', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='openaitranslator',
            name='base_url',
            field=models.URLField(default='https://api.openai.com/v1', verbose_name='API URL'),
        ),
        migrations.AlterField(
            model_name='deepltranslator',
            name='api_key',
            field=encrypted_model_fields.fields.EncryptedCharField(verbose_name='API Key'),
        ),
        migrations.AlterField(
            model_name='microsofttranslator',
            name='api_key',
            field=encrypted_model_fields.fields.EncryptedCharField(verbose_name='API Key'),
        ),
        migrations.AlterField(
            model_name='openaitranslator',
            name='api_key',
            field=encrypted_model_fields.fields.EncryptedCharField(verbose_name='API Key'),
        ),
        migrations.AlterField(
            model_name='openaitranslator',
            name='model',
            field=models.CharField(
                choices=[('gpt-4', 'gpt-4'), ('gpt-4-32k', 'gpt-4-32k'), ('gpt-3.5-turbo', 'gpt-3.5-turbo'),
                         ('gpt-3.5-turbo-16k', 'gpt-3.5-turbo-16k')], default='gpt-3.5-turbo', max_length=100),
        ),
    ]
